###################################################
### chunk number 1: 
###################################################
options(continue="  ")


###################################################
### chunk number 2: load
###################################################
library(dlnm)


###################################################
### chunk number 3: internal.mkbasis
###################################################
basis.var <- mkbasis(1:5, knots=3)
basis.var


###################################################
### chunk number 4: internal.mkbasis2
###################################################
mkbasis(1:5, type="bs", df=4, degree=2)
mkbasis(1:5, type="lin", cenvalue=4)


###################################################
### chunk number 5: internal.mklagbasis
###################################################
mklagbasis(maxlag=5, type="poly", degree=3)


###################################################
### chunk number 6: internal.thr
###################################################
mklagbasis(maxlag=5, type="integer")
mkbasis(1:5, type="dthr", knots=c(2,3))


###################################################
### chunk number 7: internal.int
###################################################
mklagbasis(maxlag=10, type="strata", knots=c(4,7))
mklagbasis(maxlag=10, type="strata", knots=c(4,7), int=F)


###################################################
### chunk number 8: internal.cen
###################################################
mkbasis(0:10, type="poly", degree=3)
mkbasis(0:10, type="poly", degree=3, cen=F)


###################################################
### chunk number 9: example1crossbasis
###################################################
basis.pm <- crossbasis(chicagoNMMAPS$pm10, vartype="lin", lagtype="poly",
	lagdegree=4, cen=F, maxlag=15)
basis.temp <- crossbasis(chicagoNMMAPS$temp, vardf=5, lagtype="strata",
	lagknots=1, cenvalue=21, maxlag=3)


###################################################
### chunk number 10: example1summary
###################################################
summary(basis.pm)


###################################################
### chunk number 11: example1model
###################################################
model <- glm(death ~  basis.pm + basis.temp + ns(time, 7*14) + dow,
	family=quasipoisson(), chicagoNMMAPS)


###################################################
### chunk number 12: example1pred
###################################################
pred.pm <- crosspred(basis.pm, model, at=0:20, cumul=T)


###################################################
### chunk number 13: example1slices
###################################################
plot(pred.pm, "slices", var=10, col=3, ylab="RR",
	main="Effects of a 10-unit increase in PM10 along lags")


###################################################
### chunk number 14: example1slicescumul
###################################################
plot(pred.pm, "slices", var=10, cumul=TRUE, ylab="Cumulative RR",
	main="Cumulative effects of a 10-unit increase in PM10 along lags")


###################################################
### chunk number 15: example1slicesnoeval eval=FALSE
###################################################
## plot(pred.pm, "slices", var=10, col=3, ylab="RR",
## 	main="Effects of a 10-unit increase in PM10 along lags")
## plot(pred.pm, "slices", var=10, cumul=TRUE, ylab="Cumulative RR",
## 	main="Cumulative effects of a 10-unit increase in PM10 along lags")


###################################################
### chunk number 16: example1effect
###################################################
pred.pm$allRRfit["10"]
cbind(pred.pm$allRRlow, pred.pm$allRRhigh)["10",]


###################################################
### chunk number 17: dataseason
###################################################
chicagoNMMAPSseas <- subset(chicagoNMMAPS, month %in% 6:9)


###################################################
### chunk number 18: example2crossbasis
###################################################
basis.o3 <- crossbasis(chicagoNMMAPSseas$o3, group=chicagoNMMAPSseas$year,
	vartype="hthr", varknots=40.3, lagtype="integer", maxlag=5)
basis.temp <- crossbasis(chicagoNMMAPSseas$temp, group=chicagoNMMAPSseas$year,
	vartype="dthr", varknots=c(15,25), lagtype="strata", lagknots=c(2,6),
	maxlag=10)


###################################################
### chunk number 19: example2modelpred
###################################################
model <- glm(death ~  basis.o3 + basis.temp + ns(doy, 4) + dow,
	family=quasipoisson(), chicagoNMMAPSseas)
pred.o3 <- crosspred(basis.o3, model, at=c(0:65,40.3,50.3))


###################################################
### chunk number 20: example2slices
###################################################
plot(pred.o3, "slices", var=50.3, ci="bars", type="p", pch=19, ci.level=0.80,
	main="Effects of 10-unit increase above the threshold (80%CI)")


###################################################
### chunk number 21: example2overall
###################################################
plot(pred.o3,"overall",xlab="Ozone", ci="lines", ylim=c(0.9,1.3), lwd=2,
	ci.level=0.80, main="Overall effect over 5 days of lag (80%CI)")


###################################################
### chunk number 22: example2noeval1 eval=FALSE
###################################################
## plot(pred.o3, "slices", var=50.3, ci="bars", type="p", pch=19, ci.level=0.80,
## 	main="Effects of 10-unit increase above the threshold (80%CI)")
## plot(pred.o3,"overall",xlab="Ozone", ci="lines", ylim=c(0.9,1.3), lwd=2,
## 	ci.level=0.80, main="Overall effect over 5 days of lag (80%CI)")


###################################################
### chunk number 23: example2effect
###################################################
pred.o3$allRRfit["50.3"]
cbind(pred.o3$allRRlow, pred.o3$allRRhigh)["50.3",]


###################################################
### chunk number 24: example3crossbasis
###################################################
basis.pm <- crossbasis(chicagoNMMAPS$pm10,vartype="lin", lagtype="strata",
	cen=F, maxlag=1)
basis.temp <- crossbasis(chicagoNMMAPS$temp, vartype="bs", vardf=5, vardegree=2,
	lagdf=5, cenvalue=21, maxlag=30)


###################################################
### chunk number 25: example3noeval eval=FALSE
###################################################
## model <- glm(death ~  basis.pm + basis.temp + ns(time, 7*14) + dow,
## 	family=quasipoisson(), chicagoNMMAPS)
## pred.temp <- crosspred(basis.temp, model, by=1)
## plot(pred.temp, xlab="Temperature",zlab="RR", theta=200, phi=40, lphi=30,
## 	main="3D graph of temperature effect")
## plot(pred.temp, "contour", xlab="Temperature", key.title=title("RR"),
## 	plot.title=title("Contour plot",xlab="Temperature",ylab="Lag"))


###################################################
### chunk number 26: example3plot3d
###################################################
model <- glm(death ~  basis.pm + basis.temp + ns(time, 7*14) + dow,
	family=quasipoisson(), chicagoNMMAPS)
pred.temp <- crosspred(basis.temp, model, at=-26:33)
plot(pred.temp, xlab="Temperature",zlab="RR", theta=200, phi=40, lphi=30,
	main="3D graph of temperature effect")


###################################################
### chunk number 27: example3plotcontour
###################################################
plot(pred.temp, "contour", xlab="Temperature", key.title=title("RR"),
	plot.title=title("Contour plot",xlab="Temperature",ylab="Lag"))


###################################################
### chunk number 28: example3overall
###################################################
plot(pred.temp, "overall", xlab="Temperature", ylim=c(0.8,1.7),
	main="Overall effect of temperature over 30 days of lag")


###################################################
### chunk number 29: example3noeval2 eval=FALSE
###################################################
## plot(pred.temp, "slices", var=-20, ci="n", col=1, ylim=c(0.95,1.15), lwd=1.5,
## 	main="Lag-specific effects at different temperature, ref. 21C")
## for(i in 1:3) lines(pred.temp, "slices", var=c(0,27,33)[i], col=i+1, lwd=1.5)
## legend("topright",paste("Temperature =",c(-20,0,27,33)), col=1:4, lwd=1.5)
## plot(pred.temp, "slices", var=c(-20,33), lag=c(0,5), col=4)


###################################################
### chunk number 30: example3slices
###################################################
plot(pred.temp, "slices", var=-20, ci="n", col=1, ylim=c(0.95,1.15), lwd=1.5,
	main="Lag-specific effects at different temperature, ref. 21C")
for(i in 1:3) lines(pred.temp, "slices", var=c(0,27,33)[i], col=i+1, lwd=1.5)
legend("topright",paste("Temperature =",c(-20,0,27,33)), col=1:4, lwd=1.5)


###################################################
### chunk number 31: example3slices2
###################################################
plot(pred.temp, "slices", var=c(-20,33), lag=c(0,5), col=4)


###################################################
### chunk number 32: cleaning
###################################################
unlink("NMMAPS", recursive = TRUE)


